**************************************************************************************************
*** This do file creates the database for 
*** 																		*/
**************************************************************************************************
*** Last update: February 06, 2011 AD
**************************************************************************************************
/* Note: This do file consists of 3 parts. The first part manipulates some original data 		*/
/* and stores them in new files in the directory "/bearbeitet"; the second merges the stata 	*/
/* files and stores them in the file "PPP database complete.dta" in the		 					*/
/* directory "/bearbeitet"; the third part contains the analysis and exports the tables 		*/
/* in the directory "tables".																		*/
/* You have to change "local DIR" to the directory you copy the original stata files contained 	*/
/* in the zip file and then run the do file. 													*/
**************************************************************************************************

drop _all
clear matrix
clear mata
set mem 2000m
set mat 5000

capture net install egenmore, from(http://fmwww.bc.edu/RePEc/bocode/e)		/* checks whether egenmore is installed		*/
capture net install estout, from(http://fmwww.bc.edu/RePEc/bocode/e)		/* checks whether estout is installed		*/

***********************************************************************************
*local DIR = "C:\Users\kai_g\Dropbox\Dezentralisierung\Stata" /*change relative path to the directory where the files are located */
*local DIR = "Z:\Neuer Ordner\Forschung\Dezentralisierung\Daten\Stata" /*change relative path to the directory where the files are located */
*local DIR = "C:\Users\gehring\Dropbox\Dezentralisierung\Stata" //KAI Work
local DIR = "C:\Users\kai_g\Dropbox\Dezentralisierung Replication" //KAI Home

cd "`DIR'"
***********************************************************************************
set more off, perm

	*** checks whether folder "bearbeitet" (where transformed data are stored) and "tables" (where tables are stored) exist and creates it if not
	program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"bearbeitet"'	  	/* does folder "bearbeitet" exist? */
			if `r(confirmdir)'!=0  {  	/* folder does not yet exist */
				mkdir "bearbeitet"  	/* makes the folder  */
							  } 
			  else {
				di "folder bearbeitet already exists"
				}
		confirmdir `"tables"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
	program drop confirmdir


*******************************************************************************************************************
************* PART 1: Prepare data
*******************************************************************************************************************

*Transparency Index (Williams 2014, Journal of Comparative Economics)
	use "transparencywilliamsstata.dta", clear
	ren code CCode
	drop if CCode==""
	save "bearbeitet\transparencyindex.dta",replace
	
*** IMF government finance statistics, Spring 2012, Panel data
*** Variables Included: 
** Key: So far only 3-digit World Bank country code, added three letter country code CCode and year
	*

	use "IMF_GFS.dta",clear
	merge m:m COUNTRY_CODE using "CountryCode.dta"  //Add three letter country code as key
	drop if _merge!=3
	drop _merge
	ren ccode CCode
	order CCode, before( COUNTRY_CODE)
	ren COUNTRY_NAME country
	ren  I1972  i1972
	ren  I1973 i1973
	ren  I1974 i1974
	ren  I1975 i1975
	ren  I1976 i1976
	ren  I1977 i1977
	ren  I1978 i1978
	ren  I1979 i1979
	ren  I1980 i1980
	ren  I1981 i1981
	ren  I1982 i1982
	ren  I1983 i1983
	ren  I1984 i1984
	ren  I1985 i1985
	ren  I1986 i1986
	ren  I1987 i1987
	ren  I1988 i1988
	ren  I1989 i1989
	ren  I1990 i1990
	ren  I1991 i1991
	ren  I1992 i1992
	ren  I1993 i1993
	ren  I1994 i1994
	ren  I1995 i1995
	ren  I1996 i1996
	ren  I1997 i1997
	ren  I1998 i1998
	ren  I1999 i1999
	ren  I2000 i2000
	ren  I2001 i2001
	ren  I2002 i2002
	ren  I2003 i2003
	ren  I2004 i2004
	ren  I2005 i2005
	ren  I2006 i2006
	ren  I2007 i2007
	ren  I2008 i2008
	ren  I2009 i2009
	ren  I2010 i2010
	ren  I2011 i2011
	ren  I2012 i2012
	reshape long i, i(COUNTRY_CODE DESCRIPTOR GOVERNMENT_LEVEL) j(year)
	*Now calculate ratios before reshaping. 
	encode DESCRIPTOR,generate(descriptor) label(DESCRIPTOR)  //Create numerical variable for descriptor variables
	encode GOVERNMENT_LEVEL, gen(gov_level) label(GOVERNMENT_LEVEL) //(Generate numerical variable for government levels)
	tostring descriptor, gen(Descriptor)   //Need new variable without blanks to reshape
	gen Var= Descriptor+ GOVERNMENT_LEVEL
	*label save DESCRIPTOR using label  //save label to rename the variables later. Copy label to excel file rename.xls to get the code for renaming
	label list DESCRIPTOR


	drop DESCRIPTOR GOVERNMENT_LEVEL SERIES_CODE descriptor Descriptor gov_level

	*After reshape we want to keep 4 number per country and year
	reshape wide i, i(country COUNTRY_CODE CCode year) j(Var) string
	label var i1GG "Compensation of employees
	label var i2GG "Consumption of fixed capital
	label var i3GG "Exp_Grants
	label var i4GG "Expense
	label var i5GG "Grants
	label var i6GG "Grants from general government units
	label var i7GG "Grants to general government units
	label var i8GG "Interest
	*label var i9GG "Interest to other general government units
	label var i10GG "Other expense
	label var i11GG "Other revenue
	label var i12GG "Other taxes
	label var i13GG "Revenue
	label var i14GG "Social benefits
	label var i15GG "Social contributions
	label var i16GG "Subsidies
	label var i17GG "Taxes
	label var i18GG "Taxes on goods and services
	label var i19GG "Taxes on income, profits, and capital gains
	label var i20GG "Taxes on international trade and transactions
	label var i21GG "Taxes on payroll and workforce
	label var i22GG "Taxes on property
	label var i23GG "Use of goods and services
	label var i1LG "Compensation of employees
	label var i2LG "Consumption of fixed capital
	label var i3LG "Exp_Grants
	label var i4LG "Expense
	label var i5LG "Grants
	label var  i6LG "Grants from general government units
	label var  i7LG "Grants to general government units
	label var  i8LG "Interest
	label var  i9LG "Interest to other general government units
	label var  i10LG "Other expense
	label var  i11LG "Other revenue
	label var  i12LG "Other taxes
	label var  i13LG "Revenue
	label var  i14LG "Social benefits
	label var  i15LG "Social contributions
	label var  i16LG "Subsidies
	label var  i17LG "Taxes
	label var  i18LG "Taxes on goods and services
	label var  i19LG "Taxes on income, profits, and capital gains
	label var  i20LG "Taxes on international trade and transactions
	label var  i21LG "Taxes on payroll and workforce
	label var  i22LG "Taxes on property
	label var  i23LG "Use of goods and services
	label var  i1SG "Compensation of employees
	label var  i2SG "Consumption of fixed capital
	label var  i3SG "Exp_Grants
	label var  i4SG "Expense
	label var  i5SG "Grants
	label var  i6SG "Grants from general government units
	label var  i7SG "Grants to general government units
	label var  i8SG "Interest
	label var  i9SG "Interest to other general government units
	label var  i10SG "Other expense
	*label var  i11SG "Other revenue
	label var  i12SG "Other taxes
	label var  i13SG "Revenue
	*label var  i14SG "Social benefits
	label var  i15SG "Social contributions
	label var  i16SG "Subsidies
	label var  i17SG "Taxes
	label var  i18SG "Taxes on goods and services
	label var  i19SG "Taxes on income, profits, and capital gains
	label var  i20SG "Taxes on international trade and transactions
	label var  i21SG "Taxes on payroll and workforce
	label var  i22SG "Taxes on property
	label var  i23SG "Use of goods and services
	*********************************************
	*create Decentralization variables
	*1.Sub-national expenditures (% of total expenditures)
	*Theoretically possible to deduct interest payments as well, but might be incorret
	* 1st Choice: Interest payments are not deducted
	gen Sub_Exp= (i4LG- i7LG   +   i4SG - i7SG) / (i4GG)
	replace Sub_Exp= (i4LG- i7LG+i4SG ) / (i4GG) if    i7SG==. 
	replace Sub_Exp= (i4LG- i7LG ) / (i4GG) if   i4SG==. &  i7SG==. 
	 replace Sub_Exp= (i4LG +i4SG ) / (i4GG) if   i7SG==. & i7LG==.
	 /*gen Sub_Exp= (i4LG- i7LG- i9LG   +   i4SG - i7SG- i9SG ) / (i4GG)
	*Insert values where there is no state level
	replace Sub_Exp= (i4LG- i7LG- i9LG+i4SG-i7SG ) / (i4GG) if   i9SG==.
	replace Sub_Exp= (i4LG- i7LG- i9LG+i4SG-i9SG ) / (i4GG) if    i7SG==. 
	replace Sub_Exp= (i4LG- i7LG- i9LG+i4SG ) / (i4GG) if    i7SG==. | i9SG==.
	replace Sub_Exp= (i4LG- i7LG- i9LG) / (i4GG) if   i4SG==. |  i7SG==. | i9SG==.
	*Insert value for missing interest or grant payments
	replace Sub_Exp= (i4LG- i7LG) / (i4GG) if   i4SG==. &i9LG==.|  i7SG==. &i9LG==.| i9SG==. &i9LG==.
	replace Sub_Exp= (i4LG- i9LG) / (i4GG) if   i4SG==. &i7LG==.|  i7SG==. &i7LG==.| i9SG==. &i7LG==.
	replace Sub_Exp= (i4LG) / (i4GG) if   i4SG==. &i7LG==.&i9LG==.|  i7SG==. &i7LG==.&i9LG==.| i9SG==. &i7LG==.&i9LG==. */
	*2. Sub-national revenues (% of total revenues)
	gen SubRev=( i13LG+ i13SG)/ i13GG
	replace SubRev=( i13LG)/ i13GG if i13SG
	*3. Vertical Imbalance (%) - To which degree of their expenditure do decentral units depend on grants from other levels (incorrect when transfer from state to local or vice versa
	*I.e. it could be that states transfer money to locals and not to the central government
	gen VerIm= (i17LG+ i17SG)/( i13LG+ i13SG)
	replace VerIm= (i17LG)/( i13LG+ i13SG) if  i17SG==.
	replace  VerIm= (i17LG)/( i13LG) if  i13SG==.
	*4. Tax Effort: Share of taxes that is collected by decentral units
	gen AllTaxes= ( i17LG+ i17SG )/(i17GG)
	replace  AllTaxes= (i17LG )/( i17GG)  if    i17SG==. 
	*replace AllTaxes= ( i17LG+ i17SG +i15LG)/( i15GG+ i17GG) if i15SG==.
	*replace  AllTaxes= (i17LG +i15LG )/( i15GG+ i17GG)  if    i17SG==. &i15SG==.
	*replace  AllTaxes= (i17LG +i15LG )/( i15GG+ i17GG)  if    i17SG==. &i15SG==.
	*replace  AllTaxes= (i17LG )/( i15GG+ i17GG)  if    i17SG==. &i15SG==. &i15LG==.
	*5. Share of compensation of employees that is paid for by decentral units
	gen Employees=(i1LG +i1SG)/ (i1GG)
	replace Employees=(i1LG )/ (i1GG) if i1SG==.
	keep Sub_Exp SubRev VerIm AllTaxes Employees year CCode
	sort CCode year
	foreach Var of varlist Sub_Exp SubRev VerIm AllTaxes Employees{
	replace `Var' = `Var'*100
	}
	sum Employees AllTaxes VerIm SubRev Sub_Exp

	saveold "bearbeitet\IMF_GFS.dta", replace
	clear
	***Eurostat data, 2012, accessed 04.10.2012 at http://epp.eurostat.ec.europa.eu/portal/page/portal/government_finance_statistics/data/database
	***Additional data for the first two decentralization measures for the EU countries after 2000
	***Key variable for merging: Three letter country code as "CCode" and "year"
	import excel "Eurostat2.xls", sheet("SubRev") firstrow
	reshape long y, i( CCode) j(year)
	ren y SubRevEuro
	drop GEOTIME
	replace SubRevEuro=SubRevEuro*100
	replace SubRevEuro=. if SubRevEuro==0
	save "Eurostat1.dta",replace
	clear
	import excel "Eurostat2.xls", sheet("Sub_Exp") firstrow
	reshape long y, i( CCode) j(year)
	ren y Sub_ExpEuro
	replace Sub_ExpEuro=Sub_ExpEuro*100
	replace Sub_ExpEuro=. if Sub_ExpEuro==0
	drop GEOTIME
	save "Eurostat2.dta",replace
	use  "bearbeitet\IMF_GFS.dta", clear
	merge m:m CCode year using "Eurostat1.dta"
	drop if _merge==2
	drop _merge
	replace SubRev=SubRevEuro if SubRevEuro!=.
	gen D_EurostatRev=0
	replace D_EurostatRev=1 if  SubRevEuro!=.
	merge m:m CCode year using "Eurostat2.dta"
	drop if _merge==2
	drop _merge
	replace Sub_Exp=Sub_ExpEuro if Sub_ExpEuro!=.
	gen D_EurostatExp=0
	replace D_EurostatExp=1 if  Sub_ExpEuro!=.
	drop SubRevEuro Sub_ExpEuro
	saveold "bearbeitet\IMF_GFS.dta", replace

	*******************************************************************************************************************

*** Kolo Delf Country data, 2012, 210 countries for one point in time, cross-section(time-invariant)
*** Data on ethnic fractionalization for 210 countries, from Phillip Kolo, univerisity of Gttingen
**Key variable for merging: Three Letter country code as "Ccode" */
** There are fractionalization variables for the areas geography, language, ethnic and religion, and a composite index variable delf
	use "DELF Country data",clear
	rename abbr CCode
	label variable CCode "3letter Country Code"
	*keep only relevant indices to maintainb clarity
	keep CCode wcdcountry mastercountry fearonregion groups delf delf_Partc delf_Geo delf_language delf_ethnic delf_religion
	***
	save "bearbeitet\DELF Country data.dta", replace
	********************************************************************************************************************

	*** WDI missing indicator data, all data (WDI 2012)
	use "WDI all", clear
	bysort code: count 
	gen var_count=r(N) /* contains total number of series per country */

	foreach year in 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969          ///
																	1970 1971 1972 1973 1974 1975 1976 1977 1978 1979          ///
																	1980 1981 1982 1983 1984 1985 1986 1987 1988 1989          ///
																	1990 1991 1992 1993 1994 1995 1996 1997 1998 1999          ///
																	2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 {

																	bysort code: egen c_`year'=count(_`year')
	}

	bysort code: keep if code~=code[_n-1]
	drop series scode _*

	reshape long c_, i(code) j(year) /* reshape to long format */
	gen missing=c_/var_count          

	drop c_ var_count

	replace code="ROU" if code=="ROM" /* Romania */
	replace code="COD" if code=="ZAR" /* Congo, Dem. Rep. */
	replace code="AND" if code=="ADO" /* Andorra */
	replace code="IMN" if code=="IMY" /* Isle of Man */ 
	replace code="TLS" if code=="TMP" /* Timor Leste */
	replace code="PSE" if code=="WBG" /* West Bank and Gaza */
	ren code CCode
	sort CCode year
	label var missing "Non-Missing WDI data based on all indicators"
	saveold "bearbeitet\missing.dta", replace

*************************************************************************************************************************************
*** WDI missing indicator data, four indicators (WDI 2012)
*************************************************************************************************************************************
	/*
	use "WDI all", clear
	keep if scode=="FP.CPI.TOTL.ZG" | scode=="NY.GDY.TOTL.KN" | scode=="BN.CAB.XOKA.GD.ZS" | scode=="GC.BAL.CASH.GD.ZS"

	foreach year in 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969          ///
																	1970 1971 1972 1973 1974 1975 1976 1977 1978 1979          ///
																	1980 1981 1982 1983 1984 1985 1986 1987 1988 1989          ///
																	1990 1991 1992 1993 1994 1995 1996 1997 1998 1999          ///
																	2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 {

																	bysort code: egen c_`year'=count(_`year')
	}

	bysort code: keep if code~=code[_n-1]
	drop series scode _*

	reshape long c_, i(code) j(year) /* reshape to long format */
	gen missing_4=c_/4        
	label var missing_4 "Non-Missing data, out of 4 indicators (Inflation, GDI, CAB, Cash Surplus)"
	drop c_

	replace code="ROU" if code=="ROM" /* Romania */
	replace code="COD" if code=="ZAR" /* Congo, Dem. Rep. */
	replace code="AND" if code=="ADO" /* Andorra */
	replace code="IMN" if code=="IMY" /* Isle of Man */ 
	replace code="TLS" if code=="TMP" /* Timor Leste */
	replace code="PSE" if code=="WBG" /* West Bank and Gaza */
	sort code year
	ren code CCode
	sort CCode year
	label var missing_4 "Missing WDI data share, based on four indicators"
	saveold "bearbeitet\missing_4.dta", replace
	*/
	*** WDI missing indicator data, Hollyer (WDI 2016)
*using only 3 - Economy & Growth and 20 External Debt
/* Downloaded last as of 22 May 2017
	wbopendata, language(en - English) topics(3 - Economy & Growth)  clear
	wbopendata, language(en - English) topics(20 - External Debt)  clear
	saveold "wbopen.dta", replace
*/
use  "wbopen.dta",clear
	drop yr2012 yr2013 yr2014 yr2015

	bysort countrycode: count 
	gen var_count=r(N)

	foreach var of varlist y* {
	ren `var' _`var'
	}

	ren _* _#, renumber(1960)

	foreach year in 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 	///
					1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 	///
					1980 1981 1982 1983 1984 1985 1986 1987 1988 1989	///
					1990 1991 1992 1993 1994 1995 1996 1997 1998 1999	///
					2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 {

					bysort countrycode: egen c_`year'=count(_`year')
	}

	bysort countrycode: keep if countrycode~=countrycode[_n-1]
	drop iso2code region indicatorname regioncode indicatorcode _*

	reshape long c_, i(countrycode) j(year) /* reshape to long format */
	gen miss_hollyer=c_/var_count	
	label var miss_hollyer "Hollyer Transparency, Economy & Growth and External Debt indicators in WDI 2016"
	drop c_ var_count

	rename countrycode code
	replace code="ROU" if code=="ROM" /* Romania */
	replace code="COD" if code=="ZAR" /* Congo, Dem. Rep. */
	replace code="AND" if code=="ADO" /* Andorra */
	replace code="IMN" if code=="IMY" /* Isle of Man */ 
	replace code="TLS" if code=="TMP" /* Timor Leste */
	replace code="PSE" if code=="WBG" /* West Bank and Gaza */
	rename countryname country
	ren code CCode

	saveold "bearbeitet\miss_hollyer.dta", replace	

	*** Hollyer, Rosendorf and Vreeland HRV transparency data
	*** Measuring transparency (JR Hollyer, BP Rosendorff, JR Vreeland) - Political analysis, 2014
	***Details: http://0001c70.wcomhost.com/wp2/ 
	use "HRV2013.dta", clear
	ren wdicode CCode
	keep CCode year transparencyindex
	ren transparencyindex transparencyindex_HRV
	save "bearbeitet\HRV.dta", replace	



	*** Worldbank data, 2012, 211 countries 1970-2010, panel structure
	*** Data on all variables from the Worldbank that might be relevant regarding complexity, capacity or information
	***Can be easily changed to use other indicators
	***Key variable for merging: Three letter country code as "CCode" and "year"
	use "WorldbankIndicators.dta",clear
	rename countrycode CCode
	rename countryname country
	***Reshape the data to the correct format
	reshape long v, i(country CCode i) j(year)
	drop seriescode seriesname
	reshape wide v, i(CCode country year ) j(i) string
	***Label variables
	label variable vi120 "CO2 emissions (metric tons per capita)"
	label variable vi270 "Exports of goods and services (% of GDP)"
	label variable vi345 "GDP per capita, PPP (constant 2005 international $)"
	label variable vi518 "International migrant stock (% of population)"
	label variable vi519 "International migrant stock, total"
	label variable vi540 "Labor force with secondary education (% of total)"
	label variable vi543 "Labor force with tertiary education (% of total)"
	label variable vi552 "Land area (sq. km)"
	label variable vi632 "Military expenditure (% of GDP)"
	label variable vi712 "Net migration"
	label variable vi743 "Nitrous oxide emissions (thousand metric tons of CO2 equivalent)"
	label variable vi745 "Nitrous oxide emissions in industrial and energy processes (% of total nitrous oxide emissions)"
	label variable vi749 "Oil rents (% of GDP)"
	label variable vi799 "Population in largest city"
	label variable vi802 "Population in urban agglomerations of more than 1 million (% of total population)"
	label variable vi805 "Population, total"
	label variable vi970 "Road density (km of road per 100 sq. km of land area)"
	label variable vi1223 "Roads, goods transported (million ton-km)"
	label variable vi997 "School enrollment, secondary (% net)"
	label variable vi1053 "Surface area (sq. km)"
	label variable vi1145 "Urban population (% of total)"
	label variable vi1155 "Water pollution, chemical industry (% of total BOD emissions)"
	label variable vi1156 "Water pollution, clay and glass industry (% of total BOD emissions)"
	label variable vi1157 "Water pollution, food industry (% of total BOD emissions)"
	label variable vi1158 "Water pollution, metal industry (% of total BOD emissions)"
	label variable vi1159 "Water pollution, other industry (% of total BOD emissions)"
	label variable vi1160 "Water pollution, paper and pulp industry (% of total BOD emissions)"
	label variable vi1161 "Water pollution, textile industry (% of total BOD emissions)"
	label variable vi1162 "Water pollution, wood industry (% of total BOD emissions)"
	label variable vi568 "Literacy rate, adult total (% of people ages 15 and above)"
	label variable vi148 "Completeness of birth registration (%)"
	label variable vi1003 "School enrollment, tertiary (% gross)"
	ren vi1003 TertEduc

	gen Waterpollution= (vi1155+vi1156+vi1157+vi1158+vi1159+vi1160+vi1161+vi1162)/8
	label var Waterpollution "Average water pollution % of total Bod emissions"
	*Generates average yearly net migration
	bysort CCode:replace vi712 = vi712[_n+1]/5 if vi712 ==.
	bysort CCode:replace vi712 = vi712[_n+1] if vi712 ==.
	bysort CCode:replace vi712 = vi712[_n+1] if vi712 ==.
	bysort CCode:replace vi712 = vi712[_n+1] if vi712 ==.
	replace vi712 = vi712[_n+1] if vi518!=.
	bysort CCode:ipolate vi518 year,gen(MigrantShare) //linearly intrapolate the share of migrants
	label var MigrantShare "International migrant stock (% of population)"
	drop vi518
	bysort CCode:ipolate vi749  year,gen(OilRents) //linearly intrapolate the share of migrants
	label var OilRents "Oil rents (% of GDP)"
	*Generate relative share of population that lives in largest city
	gen PopLargestCity=vi799/ vi805
	label var PopLargestCity "% of population that lives in largest city"
	****
	save "bearbeitet\Worldbank.dta", replace
	clear
	
	******************************************************************************************************************************************
	*** Worldbank data, 2011, World Bank Analytical Country Classifications, by GNI per capita in US$ (Atlas methodology)
	*** Data  from the Worldbank that yields the respective Development rating in the specific year-
	***Key variable for merging: Three letter country code as "CCode" and "year"
	import excel "Country classifications WBtime varying.xls", sheet("Country Analytical History (2)") firstrow
	reshape long v, i(CCode) j(year)
	sort CCode year
	ren v WBCountryclass
	label var WBCountryclass "Development classification based on GNI per capita, time varying"
	save "bearbeitet\Country classifications.dta",replace
	clear
	
	
*** Treisman, Treisman 2007, availability (mid 1990s, averages, 81 countries), cross-section
/***Data on fiscal, administrative and political decentralization: Sources for variables in Fan et al. 2009, Political Decentralization and corruption, only cross section
***Original data set includes objective corruption reports with about 100 observations per country, we need only one per country. All decentralization variables are averaged over the 1990's
***Relevant Variables included: g*/
**Key variable for merging: Three Letter country code as "Ccode" */
	use "Treisman 2007.dta", clear
	gen year=2002
	move year country
	*Keep only one observation per country, the decentralization variables are all constant for one country
	bysort countryname : gen Limit=_n
	keep if Limit==1
	***Rename some variables for clarification
	ren legor Legalorigin
	***Drop all corruption variables not related to our research
	drop ori_estb o_priv r_now gvt_pct ps_pct vsal vfas competitor ladv_ch tlg_days coll papr hint spcn lckm acfk acnb expf lesf crd afs_yn ias_yn mny_day sector cmpt_maj ///
	size_f industrydummy exp_pct exp_yn frk_pct yr_estb foreigndum gvt_yn op_ctry corr t_smgt sdpy concat law_pred av_lreg int_lrg fi_crt hu_crt q_crt aff_crt cst_crt enf_crt cf_crt ///
	cf3_crt gcf infr gcpi infl exr scri ocri txreg gcorr apay pssale hld_123 tadm_reg off_sr telpy licpy taxpy conpy cuspy region1 qcbk adpy corctn_g bri_ptr gvoc_ch lc fmny_dy ltloan ///
	juds antcomp vdebt inta_yn apay_xtr crtpy lawpy othpy nflc_exe nflc_leg nflc_min nflc_reg eco_pred fin_ob1 cmph cmpi fhq_cty salf_iod electpy salf_iud age agecat logsales logfixasset ///
	logfirmage  log_settler_mortality TIcorrupt ti2000 logpepden1500 subemployeenum cenemployeenum corruptdum corrgroup foreigndumtrun y courtbri subgemppop cgemppop Limit licenbri taxbri ///
	contractbri telbri cusbri corruptfre faircourt enforceability uphold quickcourt corruptobstacle Y prot00 fuel00 cr pcr pb info pstring divindex cgovind4 ercmon y1 country ///
	gdppsqr gdppc95 popunit population98 cenemptolabor logavegdpcapita WBcorrupt00 corruptmean pubilcempl toptax poliright illiteracy ethnic school autressizerev policesizebot ///
	roadlocalsizebot tiersshared autressizebot fedsizebot fiscemp pbage pcrage subrevshare formercolony source democratic46yr telcorrupt fiscalrevgdp surfacearea corrupt98 law98 ///
	regulate98 effective98 stable98 voice98 leg_british gdppp99 lngdpp99 alldem00 presdpi fh_press yearopen imp2000 procdj timedj autressize botelautres subrevgdp1 pc_gdp lncdays ///
	govrevgdp shared roadlocal policelocal roadregion policeregion britcol
	*Adjust botel variable
	replace botel=1 if botel==0.5
	*Label variables from Fan et al. Paper 2009, detailed in working paper on Treisman's Homepage
	label variable primary_education "subnational government ovolved in primary education"
	label variable infrastructure "subnational government ovolved in infrastructure"
	label variable policing "subnational government ovolved in policing"
	label variable fedelupd `"Dummy, classified as "federal" by Elazar 1995),with updates: Bosnia and "'
	label variable fedelaz `"Dummy, classified as "federal" by Elazar (Publius, 1995)"'
	**Update manually
		rename code CCode
	label variable CCode "3letter Country Code"
		keep CCode year residualautonomy botel resid auton autres fedelaz fedelupd
	save "bearbeitet\Treisman.dta", replace
	
*** Harvard DemocracyTime-seriesDataset, 2009, Data for 1971-2007, but not all variables, 125-160 countries per year
***Includes data on colonial origin, GDP from the World Bank and media circulation
***Key variable for merging: Three letter country code as "CCode" and "year"
	use "Democracy_TimeSeries_Data_January2009_StataSE", clear
	replace CCode="JPN" if Nation=="Japan"  // Fill up missing codes
	*Keep possibly relevant variables, mostly regional dummies, constitutional origin, conflicts, political charactericstics and ethnic diversity, plus informational stage (internet e.g.)
	keep year Nation CCode  Britcol colony  POLstand ///
	fragment durable sf regtrans  CHEIBUB frac_eth frac_lan frac_rel  ELF Fearon  fedtype Admin Political   execage   delta19 ///
	 frac partyage    GDP_WB  delta26  polit01   interstate  Conflictups  FHPressCat Banksmediascale Africa Asia CEurope Nam Sam Scan MEast WEuro Geering ///
	 computer2 computer3 computer6 delta15 
	 foreach var in Region_Af Region_Asia Region_NAM Region_SAM Region_EU RegionME{
	 gen `var'=0
	 }
	 *Recode fedtype so that 1 refers to a non-unitary state
	 clonevar fedtype2=fedtype
	 replace fedtype2=1 if fedtype==0
	 replace fedtype2=0 if fedtype==1
	 drop fedtype
	 ren fedtype2 fedtype
	 *Fill up the missing years 
	bysort CCode: egen fedtype2=mean(fedtype)
	drop fedtype
	ren fedtype2 fedtype
	label values fedtype fedtype 
 	   replace Region_Af=1 if Africa==1
	   replace Region_Asia=1 if Asia==1
	   replace Region_NAM=1 if Nam==1
	   replace Region_SAM=1 if Sam==1
	   replace Region_EU=1 if CEurope==1 | Scan==1 
	   replace RegionME =1 if MEast==1
	   replace Region_EU=1 if CCode=="AUT" |CCode=="BEL" |CCode=="CHE" |CCode=="CYP" |CCode=="DEU" |CCode=="ESP" |CCode=="FRA" |CCode=="GBR" |CCode=="GRC" ///
	   |CCode=="IRL"  |CCode=="ITA" |CCode=="LIE" |CCode=="LUX" |CCode=="MLT" |CCode=="MON" |CCode=="NLD"	|CCode=="PRT" |CCode=="SMA" |CCode=="SMA"
	   replace  RegionME=0 if CCode=="IRL"
	   *Create regional dummies Region_Af Region_Asia Region_NAM Region_SAM Region_EU RegionME
	   replace FHPressCat=0 if FHPressCat==9
	sort CCode year
	*bysort CCode: gen Conflicts = Conflictups +Conflictups[_n-1] + Conflictups[_n-2]+Conflictups[_n-3]+Conflictups[_n-4]
	*label var Conflicts "No of interstate conflicts in the last 5 years"
	***
	save "bearbeitet\Democracy_TimeSeries.dta", replace
******************************************************************************************************************************************
************************************************************************************************************************+
	*** ICRG, 2009
	*** Data on perceptions of risk, mainly external conflicts
	***Key variable for merging: Three letter country code as "CCode" and "year"

	use "ICRG2.dta",clear
	merge m:1 country using "icrg_codes.dta",keep(3) nogen
	ren ccode CCode
	drop if missing(CCode)
	egen No=group(variable)
	drop if CCode=="ZAR"
	levelsof variable, local(levels)  
		drop variable country
	reshape wide value, i(year CCode) j(No) 
	local i=1
	while `i' < 14 {
	 foreach l of local levels {
	label var value`i' "`l'"
	local i = `i' + 1
	}
	}
	ren  value2 Corruption
	ren  value4 EthnicTensions
	replace EthnicTensions=6-EthnicTensions //Adjust so higher value means more tensions
	ren value5 RiskofExternalConflicts
	ren value6 GovernmentStability
	replace RiskofExternalConflicts=12-RiskofExternalConflicts  //Adjust so higher value means more risk
	keep year CCode Corruption EthnicTensions RiskofExternalConflicts GovernmentStability
	sort CCode year
	saveold "bearbeitet\ICRG.dta", replace	
	
*** COMPARATIVE CONSTITUTIONS PROJECT, accessed online 08.04.2013, at http://www.comparativeconstitutionsproject.org/Downloads.aspx
*** Data on constitutional structure of nations, variables of interest federal_2  and fedrev
***Key variable for merging: Three letter country code as "CCode" and "year", CCode needs to be created
	import excel "ComInstitutions.xlsx", sheet("Tab2") firstrow clear
	ren Ccode CCode
	merge 1:1 cowcode using "ccpcncv1_0.dta", keep (1 3) nogen
	keep CCode systyear  federal_2 fedrev
	label var federal_2 "1 existence of subsidary units, 0 otherwise"
	label var fedrev "1 national can overrul regional, 2 if not"
	saveold  "bearbeitet\CCP.dta", replace	
	

	
*** Freedom House Data, accessed online 09.10.2012, at http://www.freedomhouse.org/report-types/freedom-press
*** Data on Freedom of the press, old data recoded as: (F =25, PF=50, NF=75), Print Freedom chosen
***Key variable for merging: Three letter country code as "CCode" and "year"
	use "Freedom of the Press.dta",clear
	drop if CCode=="."
	reshape long v, i(CCode) j(year)
	ren v PressFreedom
	label var PressFreedom "Freedom House Press Freedom"
	replace PressFreedom =(PressFreedom-100)*(-1) //Adjust so higher values mean more freedom
	save "bearbeitet\Freedom of the Press.dta",replace
	
	
*** Database of Political Institutions 2012 (updated Jan. 2013)
*** "Thorsten Beck, George Clarke, Alberto Groff, Philip Keefer, and Patrick Walsh, 2001. "New tools in comparative political economy: The Database of Political Institutions." 15:1, 165-176 (September), World Bank Economic Review.
***Provides updated values for muni and author variables that indicate the independence and decision power of local units
*** Political data, downloaded from http://econ.worldbank.org/WBSITE/EXTERNAL/EXTDEC/EXTRESEARCH/0,,contentMDK:20649465~pagePK:64214825~piPK:64214943~theSitePK:469382,00.html on March 6, 2013
*** Key: 3-digit ISOcountry code, renamed  CCode , year as time dimension
	use "DPI2012.dta",clear
	ren ifs CCode
	keep  CCode year author govfrac tensys muni state
	gen muni2=muni
	replace muni2=1 if  muni==1 |muni==2
	replace muni2=0 if muni==0
	drop muni
	ren muni2 muni
	label var muni "Local or state Legislature or  executive locally elected"
	replace muni=1 if state==2 |state==1
	replace muni=0 if state==0
	replace muni=. if muni==-999
	replace author=. if author==-999
	save "bearbeitet\DPI2012.dta", replace
			
	
*** PWT7.1, accessed online 24.09.2012, at ...website...
*** Data on PPP adjusted GDP and on openness
***Key variable for merging: Three letter country code as "CCode" and "year"

	insheet using "PWT7.1.csv", nodouble comma clear
	
	label var openk "Openness at 2005 constant prices (%)"
	label var rgdpch "PPP Converted GDP Per Capita (Chain Series), at 2005 constant prices"
	label var rgdpl "PPP Converted GDP Per Capita (Laspeyres)"
	ren isocode CCode
		replace CCode="DEU" if CCode=="GER"
		
	keep CCode year pop rgdpl rgdpch openk
	sort CCode year
	gen logGDP=log(rgdpl)
	label var rgdpl "PPP Converted GDP Per Capita"
	label var logGDP "log PPP Converted GDP Per Capita"
	save"bearbeitet\PWT.dta",replace

*** World Telecommunications /ICT Indicators Database
*** Data on technology and telecommunication
***Key variable for merging: Three letter country code as "CCode" and "year"
	use "ICTold.dta",clear
	ren country_code CCode
	reshape long _,i(CCode series_name series_code  ) j (year)
	drop country_name series_name varname
	ren _ Var

	reshape wide Var,i(CCode  year) j(series_code) string
	label var VarI143 "Faults per 100 fixed telephone lines per year "
	label var VarI91 "Fixed telephone lines per 100 inhabitants "
	label var VarI152B "Monthly subscription for business telephone service (US$) "
	label var VarI141 "Percentage of fixed telephone faults cleared by next working day "
	label var VarXHH "Percentage of households with a fixed line telephone "
	label var VarXH "Percentage of households with a radio "
	label var VarI1163 "Percentage of localities with telephone service "

	save "bearbeitet\ICT.dta", replace



****************************************************************************************************************
************* PART 2: merge databases
****************************************************************************************************************

****************************************************************************************************************
*******************************IMF Government Finance data******************************************************
****************************************************************************************************************

	use "bearbeitet\IMF_GFS.dta",clear
	merge m:m CCode year using "bearbeitet\Worldbank.dta"
	drop if _merge==2
	drop _merge
	merge m:m CCode  using "bearbeitet\DELF Country data.dta"
	drop if _merge==2
	drop _merge
	merge m:m CCode  using "bearbeitet\Democracy_TimeSeries.dta"
	encode CCode,gen(ccode) label(CCode)
	* Problem xtset reports that there are repeated time values within the panel, the country Serbia with the CCode "SRB" is in their twice	each year (most years)
	sort CCode year 
	bysort CCode year : gen no=[_n] if CCode=="SRB"
	drop if no==2
	drop no // Try to solve problem
	drop if CCode=="AGO" &year==1980&Africa==.
	drop if CCode=="BEN" &year==1971&delta19==.
	drop Africa Asia CEurope Nam Sam Scan MEast WEuro
	drop delta19
	drop if _merge==2
	drop _merge
	
	merge m:m CCode year using "bearbeitet\ICRG.dta", nogen keep(1 3)

	merge m:m CCode year using "bearbeitet\PWT.dta", nogen keep(1 3)

	merge m:m CCode year using "bearbeitet\ICT.dta", nogen keep(1 3)

	merge m:m CCode  using "bearbeitet\Treisman.dta", nogen keep(1 3)
	
	merge m:m CCode year using "bearbeitet\miss_hollyer.dta", nogen keep(1 3)

	merge m:m CCode year using "bearbeitet\missing.dta", nogen keep(1 3)

	merge m:m CCode year using "bearbeitet\Country classifications.dta", nogen keep(1 3)

	merge m:m CCode year using  "bearbeitet\Freedom of the Press.dta", nogen keep(1 3)
	
	merge 1:1 CCode year using "bearbeitet\DPI2012.dta", nogen keep(1 3)
	
	merge 1:1 CCode year using "bearbeitet\transparencyindex.dta", nogen keep(1 3)
	*HRV Index, Hollyer et al.
	merge 1:1 CCode year using "bearbeitet\HRV.dta", nogen keep(1 3)
	
	xtset ccode year

	*Recode colony to be in line with Treisman (2006)
	bysort CCode:ipolate durable year,gen(RegimeDurability) epolate
	replace RegimeDurability=. if RegimeDurability<=0
	tab colony,gen(Col)
	             //Recode colony to be in line with Treisman (2006)
	replace sf =0 if sf==.
	ren sf CollapseDummy
	*Create Median GDP Split
	gen SplitGDP=0
	egen median=median(rgdpl)
	replace SplitGDP=1 if rgdpl>=median
	drop median
	label define SplitGDP 1 "Above Median PPP GDP" 0 "Below median PPP GDP"
	label values SplitGDP SplitGDP
	label var SplitGDP "Indicates development status"
	
	sort CCode year
	foreach var of varlist frac_eth frac_lan frac_rel vi552  ELF  Col* Region_Af Region_Asia Region_NAM Region_SAM Region_EU RegionME{
	*by CCode: carryforward `var',replace
	by CCode: carryforward `var',replace 
	gsort CCode -year
	by CCode: carryforward `var',replace 
	}
	quietly foreach var of varlist Region_Af Region_Asia Region_NAM Region_SAM  RegionME{
	replace `var'=0 if CCode=="SRB"
	}
	replace Region_EU=1 if CCode=="SRB"
	sort CCode year
	
	gen ExtConflict=0
	replace ExtConflict=1 if interstate[_n-1]==1
	replace ExtConflict=1 if interstate[_n-2]==1
	replace ExtConflict=1 if interstate[_n-3]==1
	replace ExtConflict=1 if interstate[_n-4]==1
	replace ExtConflict=1 if interstate[_n-5]==1
	replace ExtConflict=1 if interstate[_n]==1
	replace ExtConflict=1 if interstate[_n-6]==1
	replace ExtConflict=1 if interstate[_n-7]==1
	replace ExtConflict=1 if interstate[_n-8]==1
	replace ExtConflict=1 if interstate[_n-9]==1
	label var ExtConflict "Interstate military conflict in the last 10 years"
	*Fill up fedtype
	bysort ccode: egen fedtype2=mean(fedtype)
	drop fedtype
	ren fedtype2 fedtype

	gen period3=0 
	forvalues i = 1(1)15 {
	replace period3=`i' if year<=1971+3*`i' & period3==0
	}

	gen period5=0 
	quietly forvalues i = 1(1)15 {
	replace period5=`i' if year<=1971+5*`i' & period5==0
	}
	drop if year==2012 //Not enough variables in that year
	gen period10=0 
	quietly forvalues i = 1(1)5 {
	replace period10=`i' if year<=1971+10*`i' & period10==0
	}
	*gen period dummies
	quietly foreach var in year period3 period5 period10 ccode {
	 tab `var',gen(`var'_)
	 drop `var'_1
	}

	bys CCode: gen count= [_n]
	by CCode, sort:egen nonmiss = min(cond(Sub_Exp != ., year,.)) //Returns the first year with nonmissing SubExp
	*Generate Initial value
	gen byte first = year == nonmiss 
	replace first=. if first==0
	gen Init=Sub_Exp*first
	bys CCode: egen InitSub_Exp=mean(Init)      
	drop Init first nonmiss

	order period3 period5 period10,after(year)
	ren vi1145 UrbanPop
	ren vi712 NetMigr
	ren vi552 LandArea
	ren vi799 PopLCity
	ren vi120 CO2
	ren VarI91 InfoTransmission
	ren vi805 Pop
	 replace frac_eth=frac_eth*100
	 replace frac=frac*100
	 replace missing=missing*100
	 replace miss_hollyer=miss_hollyer*100
	 
	*Log variables if necessary
	replace LandArea=log(LandArea)
	label var LandArea "Log Land area (Sq. km)"
	replace Pop = log(Pop)
	label var Pop "Log Population"
	sort CCode year
	by CCode: carryforward LandArea,replace
	save "bearbeitet\Decentralization.dta",replace
	
***********************************************************************************************************************
*************Labeling and adjusting final dataset********************************************************************
*********************************************************************************************************************

	use "bearbeitet\Decentralization.dta",clear
	*Summary statistics
	xtsum Sub_Exp SubRev VerIm AllTaxes Employees informationtransparency accountabilitytransparency transparencyindex

	*Generate variable that counts the average number of observations for the dependent variable per country
	bys ccode: egen CountS=count(Sub_Exp)
	label var CountS "Number of observations for the Sub_Exp per country"
	sum CountS if CountS>=1,detail 
	graph twoway (histogram CountS if CountS>=1,percent   fcolor(dknavy)  ///
	xtitle("Observations for Sub-Expenditure per country",margin(mediumsmall) ) ///
	graphregion(fcolor(white) ifcolor(white) lcolor(white) icolor(white)) scheme(  s1mono ) plotregion(fcolor(white)  lcolor(white)) )
	graph save "tables\Histogram_SubExp", replace 

	*Show correlations of information transmission variable with Banks and internet
	label var Banks " Media access (TV, Radio, papers, internet, Banks 2007)"
	label var computer6 "Computers per capita (Banks(2007)"
	label var informationtransparency "Information Index Williams 2014"
	label var accountabilitytransparency "Accountability Index Williams 2014"
	label var transparencyindex "Information and Accountability Index Williams 2014"

	estimates drop _all
	 estpost correlate InfoTransmission Banks  computer6 informationtransparency, matrix 
	 esttab using "tables\Info.txt",  replace not unstack   label  nostar  b(2) 
	 
	xtsum  Sub_Exp SubRev VerIm AllTaxes Employees CHEIBUB Col*  logGDP openk      ///
		UrbanPop NetMigr LandArea  Pop  CO2  InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel     miss_hollyer  ///
		 Corruption RiskofExternalConflicts EthnicTensions GovernmentStability frac PressFreedom MigrantShare ///
		missing  TertEduc
	des Sub_Exp SubRev VerIm AllTaxes Employees CHEIBUB Col*  logGDP openk      ///
		UrbanPop NetMigr LandArea  Pop  CO2  InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel     miss_hollyer  ///
		 Corruption RiskofExternalConflicts EthnicTensions GovernmentStability frac PressFreedom MigrantShare ///
		missing  TertEduc
		
	*The two variables for information InfoTransmission and missing/missing_4 are nearly not or even negatively correlated VarI143
	correl InfoTransmission informationtransparency missing miss_hollyer	  
	pwcorr InfoTransmission informationtransparency missing miss_hollyer	  
	corr missing miss_hollyer
	

version 11.0
*********************************************************************************************************************************************************************************************
*********************************************************************************************************************************************************************************************
****************************************************Analysis*********************************************************************************************************************************
*********************************************************************************************************************************************************************************************
*********************************************************************************************************************************************************************************************

*Output tables separated for 1year, 5 year and 10 year samples, named period
*1 and 5 years as panels, 10 years as 4 cross-sections

	quietly {
	use "bearbeitet\Decentralization.dta",clear
	xtset ccode year
	  
	forval i = 3(2) 3   {
	*foreach YVar of varlist Sub_Exp /*SubRev VerIm AllTaxes Employees */ {
	*************************************************************************************************************************************************************************
	*********************************************************3yearly********************************************************************************************************
	*************************************************************************************************************************************************************************
	collapse ccode Sub_Exp SubRev VerIm AllTaxes Employees CHEIBUB Col*  logGDP openk  informationtransparency    ///
	UrbanPop NetMigr LandArea  Pop  CO2  InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel     missing transparencyindex_HRV ///
	 Corruption RiskofExternalConflicts EthnicTensions GovernmentStability frac PressFreedom MigrantShare D_EurostatExp botel auton resid autres muni author	fedtype fedelupd   ///
	miss_hollyer InitSub_Exp  TertEduc Region_Af Region_Asia Region_NAM Region_SAM Region_EU RegionME   period`i'_*, by(CCode period`i')
	*Net migration or migrant share doesn't make a difference, miss_hollyer or missing_4 also not, CO2 is not significant, Dummy for added data from Eurostat is not significant
	/*
	collapse ccode Sub_Exp SubRev VerIm AllTaxes Employees CHEIBUB Col*  logGDP openk  informationtransparency    ///
	UrbanPop NetMigr LandArea  Pop  CO2  InfoTransmission OilRents delf delf_Geo delf_language delf_ethnic delf_religion frac_eth frac_lan frac_rel     miss_hollyer transparencyindex_HRV ///
	 Corruption RiskofExternalConflicts EthnicTensions GovernmentStability frac PressFreedom MigrantShare D_EurostatExp botel auton resid autres muni author	fedtype fedelupd   ///
	missing InitSub_Exp  TertEduc Region_Af Region_Asia Region_NAM Region_SAM Region_EU RegionME   period3_*, by(CCode period3)
	xtset ccode period3
	*/
	xtset ccode period`i'
	*Correct Colonial Dummies
	foreach Col in Col1 Col2 Col3 Col4 Col5 Col6 Col7 Col8 Col9 CHEIBUB {
	replace `Col'=0 if `Col'<=0.4
	replace `Col'=1 if `Col'>=0.6
	}

	**********************************************Lag by one period
	foreach exp in  CHEIBUB  RiskofExternalConflicts EthnicTensions GovernmentStability logGDP openk      ///
	UrbanPop NetMigr LandArea  Pop   InfoTransmission OilRents delf  frac_eth frac_lan frac_rel  frac   miss_hollyer transparencyindex_HRV ///
	missing   TertEduc PressFreedom  InitSub_Exp autres   author	fedtype fedelupd botel  muni {
	gen l_`exp'=l.`exp'
	replace `exp'=l_`exp'
	drop l_`exp'
	}
 	foreach var in autres   author	fedtype fedelupd botel  muni  {
	replace `var' =1 if `var' >0.5 & `var'==.
	replace `var' =0 if `var' <0.5 & `var'==.
	}
		
******************************************************Summary statistics:******************************************************************************************
	local period`i' period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
	local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode)	//Set sample
				
	estpost sum Sub_Exp   logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents InfoTransmission informationtransparency  miss_hollyer TertEduc    EthnicTensions GovernmentStability frac  ///
	MigrantShare RiskofExternalConflicts  Corruption PressFreedom  if e(sample)
	est sto c3
	esttab c3 using "tables\Table Appendix E.txt", cells("varlabels(`e(labels)') count mean(fmt(2)) sd(fmt(2)) min max") noobs tab label replace coeflabels( logGDP "logGDP" Sub_Exp "Decentralication" miss_hollyer  "Missing data (Hollyer)" InfoTransmission "InformationTransmission" ///
	TertEduc EducationalQuality frac_eth Heterogeneity  openk TradeOpenness UrbanPop Urbanization CHEIBUB DemocracyDummy frac GovernmentFractionalization ///
	Pop Population LandArea "(log) Land Area" MigrantShare "Migrant Share")	order (Sub_Exp   logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents InfoTransmission  informationtransparency miss_hollyer TertEduc    EthnicTensions GovernmentStability frac  ///
	 MigrantShare RiskofExternalConflicts  Corruption PressFreedom ) 		style(fixed)	 delimiter(_tab) noabbrev  b(2)
		
	estpost correl Sub_Exp   logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents InfoTransmission informationtransparency  miss_hollyer TertEduc    EthnicTensions GovernmentStability frac  ///
	MigrantShare RiskofExternalConflicts  Corruption PressFreedom ,matrix											
	est store c4
	esttab  c4 using "tables\Table Appendix G.txt",  not unstack compress noobs replace	style(fixed)		nostar	b(2) coeflabels( logGDP "logGDP" Sub_Exp "Decentralication" miss_hollyer  "Missing data (Hollyer)" InfoTransmission "InformationTransmission" ///
	TertEduc EducationalQuality frac_eth Heterogeneity LandArea "(log) Land Area"  openk TradeOpenness UrbanPop Urbanization CHEIBUB DemocracyDummy frac GovernmentFractionalization ///
	Pop Population MigrantShare "Migrant Share")	 delimiter(_tab) noabbrev order (Sub_Exp   logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents InfoTransmission informationtransparency  miss_hollyer TertEduc    EthnicTensions GovernmentStability frac  ///
	MigrantShare RiskofExternalConflicts  Corruption PressFreedom ) 	
	
/*
local period3 period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  missing   `region' `period3',vce(cl ccode)
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk   OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode)
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk   OilRents TertEduc frac_eth  miss_hollyer  Corruption RiskofExternalConflicts EthnicTensions ///
GovernmentStability frac PressFreedom MigrantShare `region' `period3',vce(cl ccode)
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer OilRents TertEduc  `region' `period3',vce(cl ccode)
correl  InfoTransmission informationtransparency transparencyindex_HRV miss_hollyer missing 

local period3 period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer OilRents TertEduc  `region' `period3',vce(cl ccode)
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency  miss_hollyer OilRents TertEduc  `region' `period3',vce(cl ccode)
reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission   OilRents TertEduc  `region' `period3',vce(cl ccode)

reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency  miss_hollyer OilRents TertEduc  `region' `period3',vce(cl ccode)

*/
	
	
*****************************************************Main regressions table 1*****************************************************
    local period`i' period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
	local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB  `region' `period3',vce(cl ccode)
	est store Table`i'1_OLSSub_Exp
	reg Sub_Exp openk InfoTransmission  OilRents TertEduc  frac_eth  miss_hollyer  `region' `period3',vce(cl ccode)
	est store Table`i'2_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode)
	est store Table`i'3_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode)
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc delf  miss_hollyer   `region' `period3',vce(cl ccode)
	est store Table`i'4_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  miss_hollyer  Corruption RiskofExternalConflicts EthnicTensions ///
	GovernmentStability frac PressFreedom MigrantShare `region' `period3',vce(cl ccode)
	est store Table`i'4_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer OilRents TertEduc  `region' `period3',vce(cl ccode)
	est store  Table`i'5_OLSSub_Exp
	
	*Now produce margin tables
	margins , dydx(frac_eth) at(InfoTransmission =(0(5)75))  vsquish post
	quietly marginsplot,  xtitle("Information Transmission",tstyle(margin(small)) size(medsmall)) xlabel(0 20 40 60 80 )  title(" ") ///
	ytitle("Marginal Effect of Heterogeneity" "on Fiscal Decentralization", linegap(1.3) tstyle(margin(medsmall)) size(medsmall) ) graphregion(color(white)) ///
	recastci( rscatter) recast(line )  yline(0) ///
	note("Dashed lines give 95%-confidence interval") 
	graph save "tables\Marginal Effect of Heterogeneity Sub_Exp`i'year.gph",replace
	*graph export "tables\Marginal Effect of Heterogeneity Sub_Exp`i'year.wmf",replace

 *margins , dydx(delf) at(Corruption =(0(0.5)6))  vsquish post
 *marginsplot
*reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB  TertEduc  c.delf##c.miss_hollyer  RegimeDurability  delf  c.miss_hollyer##c.Corruption  `region' `period3',rob
*est store  Table`i'5_OLSSub_Exp

*3 yearly with OLS and regional dummies
	estout 			Table`i'1_OLSSub_Exp Table`i'2_OLSSub_Exp Table`i'3_OLSSub_Exp Table`i'4_OLSSub_Exp  Table`i'5_OLSSub_Exp  ///
					using "tables\Table 1.txt",replace ///
					title("3-yearly data with region and period dummies, lagged independent variable Sub_Exp")  noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.2f) vacant("-") label(Coef.)) se(fmt(2) par([ ])  vacant("-") label(Std. err.))) ) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) ///
					mlabels( "(1) Baseline" "(2) Variables of interest" "(3) Complete " "(4) Reduced sample" "(5) Complete with interactions" ) ///
					stats(r2_a N, labels("Adj. R-Squared" "Number of Cases") fmt(2 0)) 	 ///
					keep(_cons logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission frac_eth OilRents TertEduc   miss_hollyer Corruption RiskofExternalConflicts EthnicTensions ///
					GovernmentStability frac PressFreedom MigrantShare c.frac_eth#c.InfoTransmission  ) drop(o.CHEIBUB,relax )  ///
					order(logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents InfoTransmission miss_hollyer   TertEduc    EthnicTensions GovernmentStability frac MigrantShare  ///
					RiskofExternalConflicts Corruption  PressFreedom  c.frac_eth#c.InfoTransmission ) ///
					indicate("Period effects =  period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14" ///
					"Region Dummies = Region_Af Region_Asia Region_NAM Region_SAM Region_EU " ) ///
					postfoot("Cluster adjusted standard errors in brackets" @starlegend)  varlabels(_cons Constant miss_hollyer Transparency InfoTransmission InformationTransmission ///
					TertEduc EducationalQuality frac_eth Heterogeneity  openk TradeOpenness UrbanPop Urbanization CHEIBUB DemocracyDummy frac GovernmentFractionalization ///
					c.frac_eth#c.InformationTransmission Heterogeneity*InformationTransmission  Pop Population)	


******************************************Federal vs. unitary countries*********************************************************************
*******************************************************************************************************************************************
********************************************Including Initial GDP*************************************************************************
*****************************************************************************************************************************************
	estimates drop _all
	local replace replace  //Set to replace first table
	foreach var in  fedtype  fedelupd autres   author muni	{
		local period`i' period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
		local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU	
	    reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer OilRents TertEduc  `region' `period3' if `var'==1
		est sto model1
		reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer  OilRents TertEduc  `region' `period3' if `var'==0
		est sto model2
		suest model1 model2, vce(cluster ccode)
		test [model1_mean]c.frac_eth#c.InfoTransmission = [model2_mean]c.frac_eth#c.InfoTransmission
		scalar `var'= r(p)
		scalar Test=r(p)
    reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission   OilRents TertEduc  miss_hollyer `region' `period3' if `var'==1, cluster(ccode)
	est sto Table2`i'`var'1
	estadd scalar Test
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission miss_hollyer  OilRents TertEduc  `region' `period3' if `var'==0,cluster(ccode)
	est sto Table2`i'`var'2

	*3 yearly with OLS and regional dummies, divided by local or federal moves first, only interaction
		estout 	Table2`i'`var'1     Table2`i'`var'2               ///
				using "tables\Table 2a.txt",`replace'  title("`var'") ///
				delimiter(_tab) noabbrev wrap	nolabel				///
				cells((b(star fmt(3) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N Test, labels("Adj. R-Squared" "Number of observations") fmt(2 0 3)) ///
				mlabel ( "Local" "Federal"  ) /*mgroups("Full sample" "Full controls", pattern(1 0  1 0)) */ ///
				keep(c.frac_eth#c.InfoTransmission )  ///
				postfoot("Cluster adjusted standard errors in brackets, includes initial decentralization level" @starlegend) ///
				varlabels( c.frac_eth#c.InfoTransmission Heterogeneity*InformationTransmission  )
				
				
	*************************Figures with interactions and initital decentralization*******************************************					  

	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer OilRents TertEduc  `region' `period3' if `var'==1
	margins , dydx(frac_eth) at(InfoTransmission =(0(5)75))  vsquish post
	quietly marginsplot,  xtitle("Information Transmission",tstyle(margin(small)) size(medsmall)) xlabel(0 20 40 60 80 )  title(" ") ///
	ytitle("Marginal Effect of Heterogeneity" "on Fiscal Decentralization (percent of GDP)", linegap(1.3) tstyle(margin(medsmall)) size(medsmall) ) graphregion(color(white)) ///
	recastci( rscatter) recast(line )  yline(0)  level(90)
	graph save "tables\Marginal Effect of Heterogeneity Sub_Exp`var'`i'year.gph",replace
	*graph export "tables\Marginal Effect of Heterogeneity Sub_Exp`var'`i'year.wmf",replace

  
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  miss_hollyer  OilRents TertEduc  `region' `period3' if `var'==0
	margins , dydx(frac_eth) at(InfoTransmission =(0(5)75))  vsquish post
	quietly marginsplot,  xtitle("Information Transmission",tstyle(margin(small)) size(medsmall)) xlabel(0 20 40 60 80 )  title(" ") ///
	ytitle("Marginal Effect of Heterogeneity" "on Fiscal Decentralization (percent of GDP)", linegap(1.3) tstyle(margin(medsmall)) size(medsmall) ) graphregion(color(white)) ///
	recastci( rscatter) recast(line )  yline(0)level(90)
	graph save "tables\Marginal Effect of Heterogeneity Sub_Exp`var'`i'yearLOC.gph",replace
	*graph export "tables\Marginal Effect of Heterogeneity Sub_Exp`var'`i'yearLOC.wmf",replace	
	**********************************************************************************************************************************
	local replace append
	}	
	
	
*******************************************Excluding missing data variables**********************************************************************					
	estimates drop _all
	local replace replace  //Set to replace first table
	foreach var in  fedtype  fedelupd autres   author muni	{
		local period`i' period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
		local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU	
	    reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission   OilRents TertEduc  `region' `period3' if `var'==1
		est sto model1
		reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission    OilRents TertEduc  `region' `period3' if `var'==0
		est sto model2
		suest model1 model2, vce(cluster ccode)
		test [model1_mean]c.frac_eth#c.InfoTransmission = [model2_mean]c.frac_eth#c.InfoTransmission
		scalar `var'= r(p)
		scalar Test=r(p)
    reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission   OilRents TertEduc   `region' `period3' if `var'==1, cluster(ccode)
	est sto Table2`i'`var'1
	estadd scalar Test
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission   OilRents TertEduc  `region' `period3' if `var'==0,cluster(ccode)
	est sto Table2`i'`var'2

	*3 yearly with OLS and regional dummies, divided by local or federal moves first, only interaction
		estout 	Table2`i'`var'1     Table2`i'`var'2               ///
				using "tables\Table 2aNomiss.txt",`replace'  title("Table 2a: Information Transmission") ///
				delimiter(_tab) noabbrev wrap	nolabel				///
				cells((b(star fmt(3) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N Test, labels("Adj. R-Squared" "Number of observations") fmt(2 0 3)) ///
				mlabel ( "Local" "Federal"  ) /*mgroups("Full sample" "Full controls", pattern(1 0  1 0)) */ ///
				keep(c.frac_eth#c.InfoTransmission )  ///
				postfoot("Cluster adjusted standard errors in brackets, includes initial decentralization level" @starlegend) ///
				varlabels(  c.frac_eth#c.InfoTransmission Heterogeneity*InformationTransmission  )
		local replace append				  
	}
	}
	
*********************************************************************************************************************************************************************
*****************************Same estimation using informationtransparency Index**************************************************************************************
**********************************************************************************************************************************************************************
	forval i = 3(2) 3   {
	estimates drop _all
    local period3 period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
	local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB  `region' `period3',vce(cl ccode)
	est store Table`i'1_OLSSub_Exp
	reg Sub_Exp openk informationtransparency  OilRents TertEduc  frac_eth  miss_hollyer  `region' `period3',vce(cl ccode)
	est store Table`i'2_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk informationtransparency  OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode)
	est store Table`i'3_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk informationtransparency  OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode)
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk informationtransparency  OilRents TertEduc delf  miss_hollyer   `region' `period3',vce(cl ccode)
	est store Table`i'4_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk informationtransparency  OilRents TertEduc frac_eth  miss_hollyer  Corruption RiskofExternalConflicts EthnicTensions ///
	GovernmentStability frac PressFreedom MigrantShare `region' `period3',vce(cl ccode)
	est store Table`i'4_OLSSub_Exp
	reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency  miss_hollyer OilRents TertEduc  `region' `period3',vce(cl ccode)
	est store  Table`i'5_OLSSub_Exp
	
	/* *Now produce marginal effects graphs, also for alternative measure 
	margins , dydx(frac_eth) at(informationtransparency =(0(5)75))  vsquish post
	quietly marginsplot,  xtitle("Information Transparency",tstyle(margin(small)) size(medsmall)) xlabel(0 20 40 60 80 )  title(" ") ///
	ytitle("Marginal Effect of Heterogeneity" "on Fiscal Decentralization", linegap(1.3) tstyle(margin(medsmall)) size(medsmall) ) graphregion(color(white)) ///
	recastci( rscatter) recast(line )  yline(0) ///
	note("Dashed lines give 95%-confidence interval") 
	graph save "tables\Marginal Effect of Heterogeneity Sub_Exp`i'year.gph",replace
	graph export "tables\Marginal Effect of Heterogeneity Sub_Exp`i'year.wmf",replace
	*/
 *margins , dydx(delf) at(Corruption =(0(0.5)6))  vsquish post
 *marginsplot
*reg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB  TertEduc  c.delf##c.miss_hollyer  RegimeDurability  delf  c.miss_hollyer##c.Corruption  `region' `period3',rob
*est store  Table`i'5_OLSSub_Exp

*3 yearly with OLS and regional dummies
	estout 			Table`i'1_OLSSub_Exp Table`i'2_OLSSub_Exp Table`i'3_OLSSub_Exp Table`i'4_OLSSub_Exp  Table`i'5_OLSSub_Exp  ///
					using "tables\Table Appendix F.txt",replace ///
					title("3-yearly data with region and period dummies, lagged independent variable Sub_Exp")  noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.2f) vacant("-") label(Coef.)) se(fmt(2) par([ ])  vacant("-") label(Std. err.))) ) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) ///
					mlabels( "(1) Baseline" "(2) Variables of interest" "(3) Complete " "(4) Reduced sample" "(5) Complete with interactions" ) ///
					stats(r2_a N, labels("Adj. R-Squared" "Number of Cases") fmt(2 0)) 	 ///
					keep(_cons logGDP  LandArea  Pop  UrbanPop CHEIBUB openk informationtransparency frac_eth OilRents TertEduc   miss_hollyer Corruption RiskofExternalConflicts EthnicTensions ///
					GovernmentStability frac PressFreedom MigrantShare c.frac_eth#c.informationtransparency  ) drop(o.CHEIBUB,relax )  ///
					order(logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents informationtransparency miss_hollyer   TertEduc    EthnicTensions GovernmentStability frac MigrantShare  ///
					RiskofExternalConflicts Corruption  PressFreedom  c.frac_eth#c.informationtransparency ) ///
					indicate("Period effects =  period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14" ///
					"Region Dummies = Region_Af Region_Asia Region_NAM Region_SAM Region_EU " ) ///
					postfoot("Cluster adjusted standard errors in brackets" @starlegend)  varlabels(_cons Constant miss_hollyer Transparency informationtransparency InformationTransparency ///
					TertEduc EducationalQuality frac_eth Heterogeneity  openk TradeOpenness UrbanPop Urbanization CHEIBUB DemocracyDummy frac GovernmentFractionalization ///
					c.frac_eth#c.informationtransparency Heterogeneity*InformationTransparency  Pop Population)	
	

************************************************************************************************************************************************************					  
****************************************************Regressions divided by unitary or federal: table 23*****************************************************
******************************************************************1 is always federal state, 0 = unitary state**********************************************
	local replace replace  //Set to replace first table
	foreach var in  fedtype  fedelupd autres   author muni	{
	local period3 period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
	local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU	
	
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency  miss_hollyer OilRents TertEduc  `region' `period3' if `var'==1
	est sto model1
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency  miss_hollyer  OilRents TertEduc  `region' `period3' if `var'==0
	est sto model2
	suest model1 model2, vce(cluster ccode)
	test [model1_mean]c.frac_eth#c.informationtransparency = [model2_mean]c.frac_eth#c.informationtransparency
	scalar `var'= r(p)
	scalar Test=r(p)
    reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency   OilRents TertEduc  miss_hollyer `region' `period3' if `var'==1, cluster(ccode)
	est sto Table2`i'`var'1
	estadd scalar Test
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency miss_hollyer  OilRents TertEduc  `region' `period3' if `var'==0,cluster(ccode)
	est sto Table2`i'`var'2
			
*3 yearly with OLS and regional dummies, divided by local or federal moves first, only interaction
	estout 	Table2`i'`var'1     Table2`i'`var'2               ///
				using "tables\Table 2b.txt",`replace'  title("Table 2b: Information Transparency") ///
				delimiter(_tab) noabbrev wrap	nolabel				///
				cells((b(star fmt(3) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N Test, labels("Adj. R-Squared" "Number of observations") fmt(2 0 3)) ///
				mlabel ( "Federal" "Unitary"  ) /*mgroups("Full sample" "Full controls", pattern(1 0  1 0)) */ ///
				keep(c.frac_eth#c.informationtransparency ) drop(o.CHEIBUB,relax )   ///
				postfoot("Cluster adjusted standard errors in brackets, includes initial decentralization level" @starlegend) ///
				varlabels(c.frac_eth#c.informationtransparency Heterogeneity*InformationTransparency  )	
	local replace append   //Set to append after first table
	}					  		 	  

****************************************************Regressions divided by unitary or federal: table 23*****************************************************
****************************************************1 is always federal state, 0 = unitary state************************************************************
****************************************************Excluding missing(data) variable as robustness check ***************************************************
************************************************************************************************************************************************************
	local replace replace  //Set to replace first table
	foreach var in  fedtype  fedelupd autres   author muni	{
    local period`i' period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
	local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU	
	
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency   OilRents TertEduc  `region' `period3' if `var'==1
	est sto model1
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency    OilRents TertEduc  `region' `period3' if `var'==0
	est sto model2
	suest model1 model2, vce(cluster ccode)
	test [model1_mean]c.frac_eth#c.informationtransparency = [model2_mean]c.frac_eth#c.informationtransparency
	scalar `var'= r(p)
	scalar Test=r(p)
    reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency   OilRents TertEduc   `region' `period3' if `var'==1, cluster(ccode)
	est sto Table2`i'`var'1
	estadd scalar Test
	reg Sub_Exp InitSub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.informationtransparency   OilRents TertEduc  `region' `period3' if `var'==0,cluster(ccode)
	est sto Table2`i'`var'2
		

*3 yearly with OLS and regional dummies, divided by local or federal moves first, only interaction
	estout 	Table2`i'`var'1     Table2`i'`var'2               ///
				using "tables\Table 2bNomiss.txt",`replace'  title("`var'") ///
				delimiter(_tab) noabbrev wrap	nolabel				///
				cells((b(star fmt(3) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N Test, labels("Adj. R-Squared" "Number of observations") fmt(2 0 3)) ///
				mlabel ( "Federal" "Unitary"  ) /*mgroups("Full sample" "Full controls", pattern(1 0  1 0)) */ ///
				keep(c.frac_eth#c.informationtransparency ) drop(o.CHEIBUB,relax )   ///
				postfoot("Cluster adjusted standard errors in brackets, includes initial decentralization level" @starlegend) ///
				varlabels(c.frac_eth#c.informationtransparency Heterogeneity*InformationTransparency  )	
	local replace append   //Set to append after first table

	}		


******************************************************Same estimations using Random Effects***********************************************************************
******************************************************Summary statistics:******************************************************************************************
*****************************************************Main regressions table3***************************************************************************************
	local period`i' period3_4 period3_5 period3_6 period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14
	local region Region_Af Region_Asia Region_NAM Region_SAM Region_EU
	xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB  `region' `period3',vce(cl ccode) re
	est store Table`i'1_OLSSub_Exp
	xtreg Sub_Exp openk InfoTransmission  OilRents TertEduc  frac_eth  missing  `region' `period3',vce(cl ccode) re
	est store Table`i'2_OLSSub_Exp
	xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  missing   `region' `period3',vce(cl ccode) re
	est store Table`i'3_OLSSub_Exp
	xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  miss_hollyer   `region' `period3',vce(cl ccode) re
	xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc delf  missing   `region' `period3',vce(cl ccode) re
	est store Table`i'4_OLSSub_Exp
	xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission  OilRents TertEduc frac_eth  missing  Corruption RiskofExternalConflicts EthnicTensions ///
	GovernmentStability frac PressFreedom MigrantShare `region' `period3',vce(cl ccode) re
	est store Table`i'4_OLSSub_Exp
	xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB openk c.frac_eth##c.InfoTransmission  missing OilRents TertEduc  `region' `period3',vce(cl ccode) re
	est store  Table`i'5_OLSSub_Exp
	*xtreg Sub_Exp logGDP  LandArea  Pop  UrbanPop CHEIBUB  TertEduc  c.delf##c.miss_hollyer  RegimeDurability  delf  c.miss_hollyer##c.Corruption  `region' `period3',rob
	*est store  Table`i'5_OLSSub_Exp

*3 yearly with OLS and regional dummies
	estout 			Table`i'1_OLSSub_Exp Table`i'2_OLSSub_Exp Table`i'3_OLSSub_Exp Table`i'4_OLSSub_Exp  Table`i'5_OLSSub_Exp  ///
					using "tables\Table Appendix H.txt",replace ///
					title("3-yearly data with region and period dummies, Random Effects")  noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.2f) vacant("-") label(Coef.)) se(fmt(2) par([ ])  vacant("-") label(Std. err.))) ) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) ///
					mlabels( "(1) Baseline" "(2) Variables of interest" "(3) Complete " "(4) Reduced sample" "(5) Complete with interactions" "(6) Developed" "(7)Developing") ///
					stats(r2_o N, labels("Adj. R-Squared" "Number of Cases") fmt(2 0)) 	 ///
					keep(_cons logGDP  LandArea  Pop  UrbanPop CHEIBUB openk InfoTransmission frac_eth OilRents TertEduc   missing Corruption RiskofExternalConflicts EthnicTensions ///
					GovernmentStability frac PressFreedom MigrantShare c.frac_eth#c.InfoTransmission  )    ///
					order(logGDP  LandArea  Pop  UrbanPop CHEIBUB frac_eth openk OilRents InfoTransmission missing   TertEduc    EthnicTensions GovernmentStability frac MigrantShare  ///
					RiskofExternalConflicts Corruption  PressFreedom  c.frac_eth#c.InfoTransmission ) ///
					indicate("Period effects =  period3_7 period3_8 period3_9 period3_10 period3_11 period3_12 period3_13 period3_14" ///
					"Region Dummies = Region_Af Region_Asia Region_NAM Region_SAM Region_EU " ) ///
					postfoot("Cluster adjusted standard errors in brackets" @starlegend)  varlabels(_cons Constant missing Missing InfoTransmission InformationTransmission ///
					TertEduc EducationalQuality frac_eth Heterogeneity  openk TradeOpenness UrbanPop Urbanization CHEIBUB DemocracyDummy frac GovernmentFractionalization ///
					  c.frac_eth#c.InformationTransmission Heterogeneity*InformationTransmission  Pop Population)	
	
}
}					  		 	  	
window manage close graph 

					
